from setuptools import setup, find_packages

with open("README.md", "r") as arq:
    readme = arq.read()

setup(
    name='reportify',
    version='0.0.1',
    license='Apache',
    author='Kevin',
    long_description=readme,
    long_description_content_type="text/markdown",
    author_email='exemplo@gmail.com',
    keywords='reportify',
    description=u'Trabalho Projeto de Sistemas',
    packages=find_packages(where="src"),
    package_dir={"": "src"},
install_requires=[
    "airbyte==0.24.2",
    "airbyte-api==0.52.2",
    "airbyte-cdk==6.48.2",
    "airbyte_protocol_models_dataclasses==0.15.0",
    "airbyte_protocol_models_pdv2==0.13.1",
    "annotated-types==0.7.0",
    "anyascii==0.3.2",
    "anyio==4.9.0",
    "asn1crypto==1.5.1",
    "attributes-doc==0.4.0",
    "attrs==25.3.0",
    "backoff==2.2.1",
    "blinker==1.9.0",
    "boltons==25.0.0",
    "boto3==1.38.5",
    "botocore==1.38.5",
    "bracex==2.5.post1",
    "cachetools==5.5.2",
    "cattrs==24.1.3",
    "certifi==2025.4.26",
    "cffi==1.17.1",
    "charset-normalizer==3.4.1",
    "click==8.1.8",
    "community==1.0.0b1",
    "contourpy==1.3.2",
    "cryptography==44.0.2",
    "cycler==0.12.1",
    "dataclasses-json==0.6.7",
    "dpath==2.2.0",
    "duckdb==1.2.2",
    "duckdb_engine==0.13.6",
    "dunam==3.1.0",
    "fonttools==4.57.0",
    "genson==1.3.0",
    "google-api-core==2.24.2",
    "google-auth==2.39.0",
    "google-cloud-bigquery==3.30.0",
    "google-cloud-bigquery-storage==2.31.0",
    "google-cloud-core==2.4.3",
    "google-cloud-secret-manager==2.23.3",
    "google-crc32c==1.7.1",
    "google-resumable-media==2.7.2",
    "googleapis-common-protos==1.70.0",
    "greenlet==3.2.1",
    "grpc-google-iam-v1==0.14.2",
    "grpcio==1.71.0",
    "grpcio-status==1.71.0",
    "h11==0.16.0",
    "httpcore==1.0.9",
    "httpx==0.28.1",
    "idna==3.10",
    "isodate==0.6.1",
    "itsdangerous==2.2.0",
    "Jinja2==3.1.6",
    "jmespath==1.0.1",
    "joblib==1.4.2",
    "jsonpatch==1.33",
    "jsonpath-python==1.0.6",
    "jsonpointer==3.0.0",
    "jsonref==0.2",
    "jsonschema==4.17.3",
    "kiwisolver==1.4.8",
    "langchain-core==0.1.42",
    "langsmith==0.1.147",
    "markdown-it-py==3.0.0",
    "MarkupSafe==3.0.2",
    "marshmallow==3.26.1",
    "matplotlib==3.10.1",
    "mdurl==0.1.2",
    "mypy_extensions==1.1.0",
    "narwhals==1.37.1",
    "network==0.1",
    "networkx==3.4.2",
    "nltk==3.9.1",
    "numpy==1.26.4",
    "orjson==3.10.17",
    "overrides==7.7.0",
    "packaging==23.2",
    "pandas==2.2.2",
    "pillow==11.2.1",
    "platformdirs==4.3.7",
    "plotly==6.0.1",
    "proto-plus==1.26.1",
    "protobuf==5.29.4",
    "psutil==6.1.0",
    "psycopg==3.2.6",
    "psycopg-binary==3.2.6",
    "psycopg-pool==3.2.6",
    "psycopg2-binary==2.9.10",
    "pyarrow==17.0.0",
    "pyasn1==0.6.1",
    "pyasn1_modules==0.4.2",
    "pycparser==2.22",
    "pydantic==2.11.4",
    "pydantic_core==2.33.2",
    "Pygments==2.19.1",
    "PyJWT==2.10.1",
    "pyOpenSSL==25.0.0",
    "pyparsing==3.2.3",
    "pyrate-limiter==3.1.1",
    "pyrsistent==0.20.0",
    "python-dateutil==2.9.0.post0",
    "python-dotenv==1.1.0",
    "python-ulid==3.0.0",
    "pytz==2024.2",
    "PyYAML==6.0.2",
    "RapidFuzz==3.13.0",
    "regex==2024.11.6",
    "requests==2.32.3",
    "requests-cache==1.2.1",
    "requests-toolbelt==1.0.0",
    "rich==13.9.4",
    "rich-click==1.8.8",
    "rsa==4.9.1",
    "s3transfer==0.12.0",
    "scipy==1.15.2",
    "serpyco-rs==1.13.0",
    "six==1.17.0",
    "sniffio==1.3.1",
    "snowflake-connector-python==3.15.0",
    "snowflake-sqlalchemy==1.7.3",
    "sortedcontainers==2.4.0",
    "SQLAlchemy==2.0.40",
    "sqlalchemy-bigquery==1.12.0",
    "structlog==24.4.0",
    "tenacity==8.5.0",
    "tomlkit==0.13.2",
    "tqdm==4.67.1",
    "typing-inspect==0.9.0",
    "typing-inspection==0.4.0",
    "typing_extensions==4.13.2",
    "tzdata==2025.2",
    "url-normalize==2.2.1",
    "urllib3==2.4.0",
    "uuid7==0.1.0",
    "wcmatch==10.0",
    "Werkzeug==3.1.3",
    "whenever==0.6.17",
    "xmltodict==0.14.2",
    "ai==1.23.1",
    "exceptiongroup==1.2.2",
    "filelock==3.18.0",
    "Flask"
],
)
